@@ -95,8 +95,8 @@ def test(datalist,model):
     correct_class = 0.0
     total_class = 0
     for datadict in datalist:
+        total_class += len(datadict)
         for key in datadict:
-            total_class += 1
             keydict = datadict[key]
             keymodel = model[key]
             if "options" in keydict:
